<?php

declare(strict_types=1);

namespace Apexl\Tests\Core\Infrastructure;

use Apexl\Io\Cache\Interfaces\CacheManagerInterface;
use Apexl\Io\Cache\Interfaces\CacheStreamInterface;
use Apexl\Io\Cache\Services\CacheStream;
use Stash\Driver\BlackHole;

class DummyCacheManager implements CacheManagerInterface
{
    public function default(): CacheStreamInterface
    {
        return $this->stream('default');
    }

    public function stream(string $name): CacheStreamInterface
    {
        return new CacheStream(new BlackHole());
    }

    public function clearAll(): void {}
}