<?php

declare(strict_types=1);

return [
    'allowed_domains' => explode(',', env('HTTP_ALLOWED_DOMAINS', 'http://localhost:8080')),
    'allowed_headers' => explode(',', env('HTTP_ALLOWED_HEADERS', 'X-Newton-Referer')),
    'backend_domain' => env('HTTP_BACKEND_DOMAIN', 'https://localhost'),
    'frontend_domain' => env('HTTP_FRONTEND_DOMAIN', 'https://localhost:8080'),
];